﻿using UnityEngine;
using System.Collections;

public class FoodBehavior : MonoBehaviour
{

    private float HorizontalVelocity = 0.0f;
    private float spawnTime = 0.0f;
    private Vector3 startPosition = Vector3.zero;

    private float RotationSpeed = 0.0f;


    private float HorizontalDistanceToTravel = 12.0f;
    private const int BeatsToTravel = 14;

    private float VerticalDistanceToTravel = 6.0f;
    private float Gravity = -16.0f;

    private float SecondsPerBounce = 1.0f;

    private int NumBounces = 0;

    // Use this for initialization
    void Awake()
    {

        spawnTime = Time.time;
        startPosition = gameObject.transform.position;

        // Calculate a horizontal velocity per second
        // We need to get from our start to our end in a certain number of beats

        float SecondsToArrive = (float)BeatsToTravel * 60.0f / GameManager.Instance.BPM;
        HorizontalVelocity = HorizontalDistanceToTravel / SecondsToArrive;


        // Calculate a few constants for calculating vertical travel
        SecondsPerBounce = 4.0f * 60.0f / GameManager.Instance.BPM;
        Gravity = -2.0f * VerticalDistanceToTravel / ((SecondsPerBounce / 2.0f) * (SecondsPerBounce / 2.0f));

        EstablishNewRotationSpeed();

    }

    void EstablishNewRotationSpeed()
    {
        RotationSpeed = Random.Range(-360f, 360f);
    }

    // Update is called once per frame
    void Update()
    {
        float movementTime = Time.time - spawnTime;

        Vector3 newPosition = startPosition;

        // Determine the correct horizontal position
        newPosition.x += HorizontalVelocity * movementTime;

        // Time shifted back some more for every bounce we've done
        movementTime -= (float)NumBounces * SecondsPerBounce;

        // Move the food to the ground
        newPosition.y += (Gravity * movementTime * movementTime) / 2.0f;

        // Set the object to the new position
        gameObject.transform.position = newPosition;

        // Set a new rotation
        gameObject.transform.Rotate(Vector3.forward * Time.deltaTime * RotationSpeed);
    }

    public void OnTriggerEnter2D(Collider2D collision)
    {
        if (collision.gameObject.CompareTag("Trampoline"))
        {
            NumBounces++;
            EstablishNewRotationSpeed();
        }
    }
}
