﻿using UnityEngine;
using UnityEngine.SceneManagement;
using System.Collections;

public class FoodSpawner : MonoBehaviour {

    private Color SpawnColor = Color.black;

    public GameObject FoodToSpawn = null;

    private int CurrentMusicRow = 0;
    private int CurrentMusicColumn = 0;

    private float StartTime = 0.0f;

    private bool LevelEnded = false;

    // Use this for initialization
    void Start() {
        CurrentMusicRow = 0;
        CurrentMusicColumn = 0;

        StartTime = Time.time;
    }

    public void Reset()
    {
        StartTime = Time.time;
    }

    // Update is called once per frame
    void Update () {

        if (LevelEnded)
        {
            if (Input.GetButtonDown("Left") || Input.GetButtonDown("Right"))
            {
                SceneManager.LoadScene("LevelSelect");
            }

        }
        else
        {
            // translate our time into an x and y co-ordinate into the texture
            Texture2D tex = GameManager.Instance.CurrentLevel.MusicSheetSprite.texture;
            int pixelsPerRow = tex.width;

            float TimeIntoTexture = Time.time - StartTime;

            // 60 sec/minute * minutes/beat * (beats / pixel)
            float timePerPixel = 60.0f / GameManager.Instance.CurrentLevel.BPM / 2.0f;

            int pixelCount = Mathf.FloorToInt(TimeIntoTexture / timePerPixel);


            int LastMusicColumn = CurrentMusicColumn;
            int LastMusicRow = CurrentMusicRow;

            CurrentMusicColumn = pixelCount % pixelsPerRow;
            CurrentMusicRow = pixelCount / pixelsPerRow;

            bool bStayedTheSame = (LastMusicColumn == CurrentMusicColumn) && (LastMusicRow == CurrentMusicRow);

            DebugHUD.TrackData("Column", CurrentMusicColumn);
            DebugHUD.TrackData("Row", CurrentMusicRow);

            if (! bStayedTheSame)
            {
                Color currentPixelColor = tex.GetPixel(CurrentMusicColumn, CurrentMusicRow);

                // Check what our next note is to spawn and spawn it if we're farther into the loop than that
                if (currentPixelColor == SpawnColor)
                {
                    SpawnFoodObject();
                }


                // Now check to see whether we should play drum line 1
                Color drumLine1Color = GameManager.Instance.CurrentLevel.BassLine1Sprite.texture.GetPixel(CurrentMusicColumn, 0);
                if (drumLine1Color == SpawnColor)
                {
                    GameManager.Instance.GetComponent<AudioSource>().Play();
                }

                bool hasNotesLeft = HasNoteInNext(32);
                if (!hasNotesLeft && transform.childCount == 0) // Song is over
                {
                    LevelEnded = true;
                    GameManager.Instance.LevelComplete();

                    // Stop the drumline
                    GameManager.Instance.GetComponent<AudioSource>().Stop();
                }
            }

        }
    }

    private bool HasNoteInNext(int n)
    {
        int x = CurrentMusicColumn;
        int y = CurrentMusicRow;

        Texture2D tex = GameManager.Instance.CurrentLevel.MusicSheetSprite.texture;
        while (n > 0)
        {
            if (y >= tex.height)
                return false;

            if (tex.GetPixel(x, y) == SpawnColor)
            {
                return true;
            }

            // Move on
            n--;
            x++;

            if (x >= tex.width)
            {
                x = 0;
                y++;
            }
        }

        return false;
    }

    private GameObject SpawnFoodObject()
    {
        GameObject result = GameObject.Instantiate(FoodToSpawn, gameObject.transform.position, Quaternion.identity) as GameObject;

        // Parent the result to ourselves for easy access later
        result.transform.SetParent(gameObject.transform);

        PlayerStats.GetInstance().FoodSpawned++;

        SpriteRenderer sr = result.GetComponent<SpriteRenderer>();
        sr.sprite = GameManager.Instance.CurrentLevel.FoodSprite;
        return result;
    }
}
