﻿using UnityEngine;
using UnityEngine.UI;
using System.Collections;

public class GameManager : MonoBehaviour {

    // Static singleton property
    public static GameManager Instance { get; private set; }

    public float BPM
    {
        get
        {
            if (CurrentLevel != null)
            {
                return CurrentLevel.BPM;
            }
            return 120.0f;

        }

        private set { }
    }

    public LevelData CurrentLevel = null;

    public GameObject gameOverPanel = null;

    public void LoadLevel(string LevelName)
    {
        GameObject LevelObject = GameObject.Find(LevelName);
        if (LevelObject != null)
        {
            CurrentLevel = LevelObject.GetComponent<LevelData>();

            GameObject animalObj = GameObject.Find("Animal");
            animalObj.GetComponent<SpriteRenderer>().sprite = CurrentLevel.AnimalSprite;

            GameObject bgImageObj = GameObject.Find("BackgroundImage");
            bgImageObj.GetComponent<SpriteRenderer>().sprite = CurrentLevel.bgArt;

            AudioSource drumAudioSource = gameObject.GetComponent<AudioSource>();
            drumAudioSource.clip = CurrentLevel.bgDrum1;

            GameObject foodEatenLine = GameObject.Find("FoodEatenLabel");
            foodEatenLine.GetComponent<Text>().text = CurrentLevel.FoodEatenLine;

            GameObject titleLine = GameObject.Find("TitleText");
            titleLine.GetComponent<Text>().text = CurrentLevel.TitleLine;

            PlayerStats.GetInstance().StartNewLevel();
        }
    }

    void Awake()
    {
        // First we check if there are any other instances conflicting
        if (Instance != null && Instance != this)
        {
            // If that is the case, we destroy other instances
            Destroy(gameObject);
        }

        Instance = this;

        LoadLevel(PlayerStats.GetInstance().NextLevelToPlay);
    }

    public void LevelComplete()
    {
        PlayerStats ps = PlayerStats.GetInstance();
        gameOverPanel.SetActive(true);
        gameOverPanel.transform.Find("FoodConsumed").gameObject.GetComponent<Text>().text = "Food consumed: " + ps.FoodConsumed + " / " + ps.FoodSpawned;
        ps.Scores[CurrentLevel.LevelIndex] = (float)ps.FoodConsumed / (float)ps.FoodSpawned;
        gameOverPanel.transform.Find("PercentageConsumed").gameObject.GetComponent<Text>().text = "Percent consumed: " + Mathf.CeilToInt(ps.Scores[CurrentLevel.LevelIndex] * 100.0f) + "%";
        // gameOverPanel.transform.Find("Image").gameObject;
        // gameOverPanel.transform.Find("FoodConsumed").gameObject;
    }

    // Return a random bouncing sound
    public AudioClip GetRandomBounceSound()
    {
        if (CurrentLevel != null)
        {
            return CurrentLevel.BounceSounds[Random.Range(0, CurrentLevel.BounceSounds.Length)];
        }
        return null;
    }

    public AudioClip GetFinishingAnimalSound()
    {
        if (CurrentLevel != null)
        {
            return CurrentLevel.AnimalSounds[0];
        }
        return null;
    }

    // Return a random animal sound
    public AudioClip GetRandomAnimalSound()
    {
        if (CurrentLevel != null)
        {
            return CurrentLevel.AnimalSounds[Random.Range(0, CurrentLevel.AnimalSounds.Length)];
        }
        return null;
    }
}
