﻿using UnityEngine;
using UnityEngine.UI;
using UnityEngine.SceneManagement;
using System.Collections;

public class LevelSelectInfo : MonoBehaviour {

    private LevelChooser currentSelection = null;
    public float LevelStartTime = 0.0f;

    private const float TimeToSelect = 1.5f;
    private bool PreviewMode = false;

    public void SetNewSelection(LevelChooser lc)
    {
        currentSelection = lc;
        LevelStartTime = Time.time + TimeToSelect;
        PreviewMode = false;

    }

    public void SetPreviewSelection(LevelChooser lc)
    {
        currentSelection = lc;
        PreviewMode = true;
    }

    public void ClearSelection()
    {
        currentSelection = null;
    }


    public Text LevelNameObject = null;
    public Text TimerObject = null;
    public SpriteRenderer LevelImage = null;

    public Sprite LockIcon = null;
    public Sprite GoldTrophyIcon = null;
    public Sprite SilverTrophyIcon = null;

    public GameObject[] CageIcons = null;

	// Use this for initialization
	void Start () {
        TimerObject = GameObject.Find("LevelLoadTimer").GetComponent<Text>();
        LevelNameObject = GameObject.Find("LevelName").GetComponent<Text>();
        LevelImage = GameObject.Find("LevelImage").GetComponent<SpriteRenderer>();
     
        // Initialize all the lock icons and stuff
        for (int iIcon = 0; iIcon < CageIcons.Length; iIcon++)
        {
            if (PlayerStats.GetInstance().IsLevelUnlocked(iIcon))
            {
                // Show silver or gold medal
                if (PlayerStats.GetInstance().Scores[iIcon] >= 1.0f)
                {
                    CageIcons[iIcon].GetComponent<SpriteRenderer>().sprite = GoldTrophyIcon;
                }
                else if (PlayerStats.GetInstance().Scores[iIcon] > 0.0f)
                { 
                    CageIcons[iIcon].GetComponent<SpriteRenderer>().sprite = SilverTrophyIcon;
                }
                else
                {
                    CageIcons[iIcon].GetComponent<SpriteRenderer>().sprite = null;
                }
            }
            else
            {
                // Show a lock
                CageIcons[iIcon].GetComponent<SpriteRenderer>().sprite = LockIcon;
            }
        }

    }

    // Update is called once per frame
    void Update () {
        if (currentSelection == null)
        {
            TimerObject.text = "";
            LevelNameObject.text = "";
            LevelImage.sprite = null;
        }
        else
        {

            if (PlayerStats.GetInstance().IsLevelUnlocked(currentSelection.LevelIndex))
            {

                LevelNameObject.text = currentSelection.DisplayName;
                LevelImage.sprite = currentSelection.DisplaySprite;

                if (PreviewMode)
                {
                    TimerObject.text = "Open Gate to Begin";
                }
                else
                {
                    float timeToLoad = LevelStartTime - Time.time;

                    // Update the displayed text fields
                    TimerObject.text = "Opening in " + timeToLoad.ToString("0.0"); ;

                    // If we've been here long enough, load the level
                    if (timeToLoad < 0.0f)
                    {
                        PlayerStats.GetInstance().NextLevelToPlay = currentSelection.LevelObjectName;
                        SceneManager.LoadScene("FrameworkScene");
                    }
                }
            }
            else
            {
                TimerObject.text = "Play previous levels to unlock";
                LevelNameObject.text = "Locked";
                LevelImage.sprite = LockIcon;
            }

        }
    }
}
